//Source file: PolicyNameValue.java
//Date: March 2007
//Policy Management Interfaces and Data Types for 3GPP TS 29.198-13 V7.0.0, Release 7

package org.csapi.jr.se.policy;

/**
 * This data structure is used to pass in a variable name-value pair in an evalPolicy() request. It is a Sequence of Data Elements of  a variable name and value
 * 
 */
public final class PolicyNameValue implements java.io.Serializable {

    private String name;
    private Object value;

    /**
     * Creates a new PolicyNameValue instance.
     */
    public PolicyNameValue () {}

    /**
     * Creates a new PolicyNameValue instance.
     * @param _name   Name of Variable.
     * @param _value   Value of variable.
     */
    public PolicyNameValue (String _name, Object _value) {

        this.name = _name;
        this.value = _value;
    }

    /**
     * This method returns a name.
     * 
     * @return a String value
     */
    public String getName() {
        return name;
    }

    /**
     * This method returns a value.
     * 
     * @return a Object value
     */
    public Object getValue() {
        return value;
    }


    /**
     * This method sets a name.
     */ 
    public void setName(String name) {
        this.name = name;
    }

    /**
     * This method sets a value.
     */ 
    public void setValue(Object value) {
        this.value = value;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PolicyNameValue)) {
            return false;
        } 
        PolicyNameValue policyNameValue = (PolicyNameValue) o;
        if ((this.name != null) && (policyNameValue.name != null)) {
            if(!(this.name.equals(policyNameValue.name)))  {
                return false;
            }
        }
        if(!(this.value == policyNameValue.value)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PolicyNameValue

