//Source file: PolicyVar.java
//Date: March 2007
//Policy Management Interfaces and Data Types for 3GPP TS 29.198-13 V7.0.0, Release 7

package org.csapi.jr.se.policy;

/**
 * This defines the TpPolicyVar type. It is analogous to the TpAttribute type. 
TpPolicyVar is a Sequence of Data Elements of  variable  name, type and value.
The following types of variables are defined: Atomic types, Record types (having named fields), and List types (where list elements could be complex types as well).
 * 
 */
public final class PolicyVar implements java.io.Serializable {

    private String varName;
    private org.csapi.jr.se.policy.PolicyType varType;
    private Object varValue;

    /**
     * Creates a new PolicyVar instance.
     */
    public PolicyVar () {}

    /**
     * Creates a new PolicyVar instance.
     * @param _varName   Name of variable.
     * @param _varType   Type of variable. Could be atomic or complex type.
     * @param _varValue   Value of variable. Note that depending on context, the AttributeValue may be NULL.
     */
    public PolicyVar (String _varName, org.csapi.jr.se.policy.PolicyType _varType, Object _varValue) {

        this.varName = _varName;
        this.varType = _varType;
        this.varValue = _varValue;
    }

    /**
     * This method returns a varName.
     * 
     * @return a String value
     */
    public String getVarName() {
        return varName;
    }

    /**
     * This method returns a varType.
     * 
     * @return a org.csapi.jr.se.policy.PolicyType value
     */
    public org.csapi.jr.se.policy.PolicyType getVarType() {
        return varType;
    }

    /**
     * This method returns a varValue.
     * 
     * @return a Object value
     */
    public Object getVarValue() {
        return varValue;
    }


    /**
     * This method sets a varName.
     */ 
    public void setVarName(String varName) {
        this.varName = varName;
    }

    /**
     * This method sets a varType.
     */ 
    public void setVarType(org.csapi.jr.se.policy.PolicyType varType) {
        this.varType = varType;
    }

    /**
     * This method sets a varValue.
     */ 
    public void setVarValue(Object varValue) {
        this.varValue = varValue;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PolicyVar)) {
            return false;
        } 
        PolicyVar policyVar = (PolicyVar) o;
        if ((this.varName != null) && (policyVar.varName != null)) {
            if(!(this.varName.equals(policyVar.varName)))  {
                return false;
            }
        }
        if ((this.varType != null) && (policyVar.varType != null)) {
            if(!(this.varType.equals(policyVar.varType))) {
                return false;
            }
        }
        if(!(this.varValue == policyVar.varValue)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PolicyVar

